@@ -129,8 +129,12 @@
                   (T_POW_EQUAL font-lock-constant-face table)
                   (T_PRINT font-lock-keyword-face table)
                   (T_PRIVATE font-lock-keyword-face table)
+                  (T_PRIVATE_SET font-lock-keyword-face table)
+                  (T_PROPERTY_C font-lock-constant-face table)
                   (T_PROTECTED font-lock-keyword-face table)
+                  (T_PROTECTED_SET font-lock-keyword-face table)
                   (T_PUBLIC font-lock-keyword-face table)
+                  (T_PUBLIC_SET font-lock-keyword-face table)
                   (T_READONLY font-lock-keyword-face table)
                   (T_REQUIRE font-lock-keyword-face table)
                   (T_REQUIRE_ONCE font-lock-keyword-face table)
